@@ -13,7 +13,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our @EXPORT_OK = qw(
     GRND_RANDOM
@@ -151,16 +151,8 @@ To install this module, run the following commands:
     make test
     make install
 
-Perl versions of the F<syscall.h> and F<sys/random.h> headers (as
-generated by the L<h2ph> tool) must be available. If you are using perl from a
-system package, this should have already been done for you. If you have built
-your own perl (and you have write permissions on its module directories), you
-may have to run this command first:
-
-    cd /usr/include && h2ph -eal syscall.h sys/random.h
-
-Apparent errors about missing internal headers such as C<Can't open
-gnu/stubs-32.h: No such file or directory> can be ignored.
+The F<syscall.h> and F<sys/random.h> headers in F</usr/include> (or at least
+their Perl versions as generated by the L<h2ph> tool) must be available.
 
 =head1 SUPPORT AND DOCUMENTATION
 
